from turbogears.widgets.base import CSSLink, JSLink, CSSSource, JSSource, \
                                    Widget, CoreWD, static, js_location
from turbogears.widgets.forms import SelectionField

class Tabber(Widget):
    """This widget includes the tabber js and css into your rendered
    page so you can create tabbed divs by assigning them the 'tabber' 
    and 'tabbertab' classes.
    """
    css = [CSSLink(static,"tabber/tabber.css", media="screen")]
    javascript = [JSLink(static, "tabber/tabber-minimized.js",
                         location=js_location.bodytop),
          JSSource("""
    /* Optional: Temporarily hide the "tabber" class so it does not "flash"
       on the page as plain HTML. After tabber runs, the class is changed
       to "tabberlive" and it will appear. */
    document.write('<style type="text/css">.tabber{display:none;}<\/style>');
    """),
    ]

class TabberDesc(CoreWD):
    name = "Tabber"
    for_widget = Tabber()
    template = """<div class="tabber">
        <div class="tabbertab"><h2>Tab 1</h2></div>
        <div class="tabbertab"><h2>Tab 2</h2></div>
        <div class="tabbertab"><h2>Tab 3</h2></div>
        </div>"""

class SyntaxHighlighter(Widget):
    """This widget includes the syntax highlighter js and css into your 
    rendered page to syntax-hightlight textareas named 'code'. The supported
    languages can be listed at the 'languages' __init__ parameter.
    """
    _lang_mapper = {
        'C' : 'shBrushCSharp.js',
        'Delphi' : 'shBrushDelphi.js',
        'JScript' : 'shBrushJScript.js',
        'Php' : 'shBrushPhp.js',
        'Python' : 'shBrushPython.js',
        'Sql' : 'shBrushSql.js',
        'Vb' : 'shBrushVb.js',
        'Xml' : 'shBrushXml.js',
    }
    css = [CSSLink(static,"sh/SyntaxHighlighter.css")]

    def __init__(self, languages=['Python', 'Xml']):
        javascript = [JSLink(static, 'sh/shCore.js', 
                             location=js_location.bodybottom)]
        for lang in languages:
            try:
                source = self._lang_mapper[lang]
                javascript.append(JSLink(static, 'sh/' + source, 
                                         location=js_location.bodybottom))
            except KeyError:
                raise ValueError, ("Unsupported language %s. Available "
                                   "languages: '%s'" % 
                                   (lang, ', '.join(self._lang_mapper.keys())))
        javascript.append(JSSource("dp.SyntaxHighlighter.HighlightAll('code');",
                                   location=js_location.bodybottom))
        self.javascript = javascript 

class SyntaxHighlighterDesc(CoreWD):
    name = "Syntax Highlighter"
    for_widget = SyntaxHighlighter()
    template = """\
    <textarea name="code" class="py">
        def say_hello():
            print "Hello world!"
    </textarea>"""

class JumpMenu(SelectionField):
    """
    Choose a link from the menu, 
    the page will be redirect to the selected link.
    """
    js = JSSource("""
    <!--
    function TG_jumpMenu(targ,f,restore){ 
      eval(targ+".location='"+f.options[f.selectedIndex].value+"'");
      if (restore) f.selectedIndex=0;
    }
    //-->
    """)
    
    template = """
    <select xmlns:py="http://purl.org/kid/ns#"
        name="${name}"
        class="${field_class}"
        id="${field_id}" 
        onchange="TG_jumpMenu('parent',this,0)"
        py:attrs="attrs"
    >
        <optgroup py:for="group, options in grouped_options"
            label="${group}"
            py:strip="not group"
        >
            <option py:for="value, desc, attrs in options"
                value="${value}"
                py:attrs="attrs"
                py:content="desc"
            />
        </optgroup>
    </select>
    """
    javascript = [js]
    _selected_verb = 'selected'
    params = ["attrs"]
    params_doc = {'attrs' : 'Dictionary containing extra (X)HTML attributes for'
                            ' the select tag'}
    attrs = {}

class JumpMenuDesc(CoreWD):
    name = "Jump Menu"
    for_widget = JumpMenu("your_jump_menu_field",
                          options=[('http://www.python.org', "Python"),
                                   ('http://www.turbogears.org', "TurboGears"),
                                   ('http://www.python.org/pypi', "Cheese Shop"),
                                   ('http://www.pythonware.com/daily/', "Daily Python")],
                          #default='http://www.turbogears.org'
                          )
